<template>
  <gree-popup class="smartwind-popup" position="bottom" get-container="body" v-model="isShow" safe-area-inset-bottom @hide="onHide">
    <gree-radio-list :value="SmartWind" :options="SmartWindList" @change="onClick" v-if="!showRadioList_β" />
    <gree-radio-list :value="SmartWind" :options="SmartWindList_β" @change="onClickSPList" v-else />
  </gree-popup>
</template>

<script>
import { popup, RadioList } from 'gree-ui';
import { types } from '@/store/types';
import { mapState, mapMutations, mapGetters, mapActions } from 'vuex';

export default {
  name: 'SmartWindPopup',
  components: {
    [popup.name]: popup,
    [RadioList.name]: RadioList
  },
  data() {
    return {
      isShow: false,
      showRadioList_β: false
    };
  },
  computed: {
    ...mapState('control', {
      SmartWindPopup: state => state.popup.SmartWindPopup,
      SmartWind: state => state.dataObject.SmartWind,
      StHt: state => state.dataObject.StHt || 0,
      Pow: state => state.dataObject.Pow
    }),
    ...mapGetters([
      'modTextKey',
      'modIdentifier',
      'modCurrentStatusName',
      'temSetVal',
      'temSetJson',
      'temMinVal',
      'temMaxVal',
      'spModCurrentStatusName',
      'spModIdentifier'
    ]),
    ...mapGetters('machine', ['statusMap']),
    SmartWindList() {
      return [
        {
          value: 1,
          text: '智能',
          brief: '智能选择空调风吹送状态'
        },
        {
          value: 2,
          text: '风随人',
          brief: '开启后，空调风跟随人吹送'
        },
        {
          value: 3,
          text: '风避人',
          brief: '开启后，空调风不跟随人吹送'
        },
        {
          value: 4,
          text: '环绕风',
          brief: '开启后，空调风环绕人吹送'
        }
      ];
    },
    SmartWindList_β() {
      return [
        {
          value: 0,
          text: '关闭'
        },
        {
          value: 2,
          text: '风随人',
          brief: '开启后，空调风跟随人吹送'
        },
        {
          value: 3,
          text: '风避人',
          brief: '开启后，空调风不跟随人吹送'
        }
      ];
    }
  },
  watch: {
    SmartWindPopup(val) {
      this.isShow = val;
    },
    Pow(val) {
      if (!val) {
        this.isShow = false;
      }
    }
  },
  mounted() {
    window.$bus.$on('isSmartWind_β', value => {
      if (value === 'SmartWind_β') {
        this.showRadioList_β = true;
      } else {
        this.showRadioList_β = false;
      }
    });
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL,
      stateMatchineInterFace: 'STATE_MACHINE_INTERFACE'
    }),
    onClick(option) {
      this.sendData({
        SmartWind: option.value,
        StHt: 0
      });
    },
    onClickSPList(option) {
      this.sendData({
        SmartWind: option.value,
        UDFanPort: 2,
        StHt: 0
      });
    },
    onHide() {
      this.SetPopup({ SmartWindPopup: false });
    }
  }
};
</script>

<style lang="scss">
.smartwind-popup {
  width: 100%;
  color: #404657;
  .gree-radio-list {
    .gree-radio-icon {
      .gree-icon.icon-font.checked {
        color: #71acf1;
      }
    }
  }
}
</style>
